@@ -26,12 +26,12 @@
 #include "annotationsketch/track.h"
 #include "core/basename_api.h"
 #include "core/cstr_api.h"
-#include "core/ensure.h"
-#include "core/hashmap.h"
-#include "core/ma.h"
+#include "core/ensure_api.h"
+#include "core/hashmap_api.h"
+#include "core/ma_api.h"
 #include "core/msort.h"
 #include "core/log.h"
-#include "core/str.h"
+#include "core/str_api.h"
 #include "core/thread_api.h"
 #include "core/undef_api.h"
 #include "core/unused_api.h"
