@@ -22,14 +22,14 @@
 #endif
 #include <fcntl.h>
 #include <unistd.h>
-#include "core/compat.h"
+#include "core/compat_api.h"
 #include "core/dynalloc.h"
 #include "core/eansi.h"
 #include "core/ebzlib.h"
 #include "core/ezlib.h"
-#include "core/hashmap.h"
-#include "core/fa.h"
-#include "core/ma.h"
+#include "core/hashmap_api.h"
+#include "core/fa_api.h"
+#include "core/ma_api.h"
 #include "core/spacepeak.h"
 #include "core/thread_api.h"
 #include "core/types_api.h"
@@ -37,7 +37,7 @@
 #include "core/xansi_api.h"
 #include "core/xbsd.h"
 #include "core/xbzlib.h"
-#include "core/xposix.h"
+#include "core/xposix_api.h"
 #include "core/xzlib.h"
 
 /* the file allocator class */
@@ -324,7 +324,7 @@ FILE* gt_xtmpfp_generic_func(GtStr *template_arg, enum tmpfp_flags flags,
   FILE *fp;
   GtStr *template;
   gt_assert(fa);
-  if (flags & TMPFP_USETEMPLATE)
+  if (flags & GT_TMPFP_USETEMPLATE)
   {
     gt_assert(template_arg);
     template = template_arg;
@@ -358,11 +358,11 @@ FILE* gt_xtmpfp_generic_func(GtStr *template_arg, enum tmpfp_flags flags,
   }
   {
     int fd = gt_mkstemp(gt_str_get(template));
-    char mode[] = { 'w', '+', flags & TMPFP_OPENBINARY?'b':'\0', '\0' };
+    char mode[] = { 'w', '+', flags & GT_TMPFP_OPENBINARY?'b':'\0', '\0' };
     fp = gt_xfdopen(fd, mode);
   }
   gt_assert(fp);
-  if (flags & TMPFP_AUTOREMOVE)
+  if (flags & GT_TMPFP_AUTOREMOVE)
   {
     gt_xremove(gt_str_get(template));
   }
