@@ -18,8 +18,8 @@
 #ifndef FASTA_READER_FSM_H
 #define FASTA_READER_FSM_H
 
-#include "core/fasta_reader.h"
-#include "core/str.h"
+#include "core/fasta_reader_api.h"
+#include "core/str_api.h"
 
 /* implements the ``fasta reader'' interface with a finite state machine
    (for educational purposes, the recursive descent parser is much faster) */
