@@ -19,22 +19,22 @@
 #include "core/assert_api.h"
 #include "core/class_alloc_lock.h"
 #include "core/cstr_api.h"
-#include "core/ensure.h"
+#include "core/ensure_api.h"
 #include "core/fileutils_api.h"
 #include "core/hashtable.h"
-#include "core/hashmap.h"
+#include "core/hashmap_api.h"
 #include "core/hashmap-generic.h"
 #include "core/log_api.h"
-#include "core/ma.h"
-#include "core/range.h"
+#include "core/ma_api.h"
+#include "core/range_api.h"
 #include "core/strand_api.h"
 #include "core/thread_api.h"
 #include "core/undef_api.h"
 #include "core/unused_api.h"
-#include "core/fa.h"
+#include "core/fa_api.h"
 #include "core/unused_api.h"
 #include "core/xansi_api.h"
-#include "core/xposix.h"
+#include "core/xposix_api.h"
 #include "extended/anno_db_gfflike_api.h"
 #include "extended/anno_db_prepared_stmt.h"
 #include "extended/anno_db_schema_rep.h"
