@@ -19,13 +19,13 @@
 #include <string.h>
 
 #include "core/basename_api.h"
-#include "core/chardef.h"
+#include "core/chardef_api.h"
 #include "core/cstr_api.h"
-#include "core/divmodmul.h"
-#include "core/fa.h"
+#include "core/divmodmul_api.h"
+#include "core/fa_api.h"
 #include "core/log_api.h"
-#include "core/ma.h"
-#include "core/safearith.h"
+#include "core/ma_api.h"
+#include "core/safearith_api.h"
 #include "core/undef_api.h"
 #include "core/unused_api.h"
 #include "core/warning_api.h"
@@ -793,7 +793,7 @@ const GtUchar *gt_condenseq_extract_encoded_range(GtCondenseq *condenseq,
               unique != NULL ||
               link != NULL);
     if (nextsep != 0 && nextsep == range.start + buffoffset) {
-      buf[buffoffset++] = SEPARATOR;
+      buf[buffoffset++] = GT_SEPARATOR;
       nextsep = condenseq_next_sep(condenseq, range.start + buffoffset);
     }
     else if (unique != NULL &&
@@ -859,7 +859,7 @@ const char *gt_condenseq_extract_decoded_range(GtCondenseq *condenseq,
   }
   buf = condenseq->buffer;
   for (idx = 0; idx < length; ++idx) {
-    if (ubuf[idx] == SEPARATOR) {
+    if (ubuf[idx] == GT_SEPARATOR) {
       buf[idx] = separator;
     }
     else {
