@@ -21,14 +21,14 @@
 #include <sys/stat.h>
 #include <unistd.h>
 
-#include "core/arraydef.h"
+#include "core/arraydef_api.h"
 #include "core/assert_api.h"
 #include "core/bittab_api.h"
-#include "core/compat.h"
+#include "core/compat_api.h"
 #include "core/cstr_api.h"
 #include "core/disc_distri_api.h"
-#include "core/ensure.h"
-#include "core/fa.h"
+#include "core/ensure_api.h"
+#include "core/fa_api.h"
 #include "core/fileutils_api.h"
 #include "core/hashmap-generic.h"
 #include "core/log_api.h"
