@@ -17,13 +17,13 @@
 
 #include <string.h>
 #include "core/array_api.h"
-#include "core/ensure.h"
-#include "core/fa.h"
+#include "core/ensure_api.h"
+#include "core/fa_api.h"
 #include "core/fileutils_api.h"
 #include "core/log.h"
-#include "core/ma.h"
-#include "core/mathsupport.h"
-#include "core/minmax.h"
+#include "core/ma_api.h"
+#include "core/mathsupport_api.h"
+#include "core/minmax_api.h"
 #include "core/range_api.h"
 #include "core/score_function.h"
 #include "core/str_api.h"
@@ -35,7 +35,7 @@
 #include "extended/extract_feature_sequence.h"
 #include "extended/feature_node.h"
 #include "extended/feature_node_iterator_api.h"
-#include "extended/feature_type.h"
+#include "extended/feature_type_api.h"
 #include "extended/node_visitor_api.h"
 #include "extended/reverse_api.h"
 #include "extended/swalign.h"
