@@ -31,13 +31,13 @@
 #include "core/codon_iterator_api.h"
 #include "core/codon_iterator_simple_api.h"
 #include "core/cstr_api.h"
-#include "core/cstr_array.h"
+#include "core/cstr_array_api.h"
 #include "core/grep_api.h"
-#include "core/hashmap.h"
+#include "core/hashmap_api.h"
 #include "core/log.h"
-#include "core/ma.h"
-#include "core/mathsupport.h"
-#include "core/range.h"
+#include "core/ma_api.h"
+#include "core/mathsupport_api.h"
+#include "core/range_api.h"
 #include "core/str_api.h"
 #include "core/strand_api.h"
 #include "core/symbol_api.h"
@@ -50,8 +50,8 @@
 #include "extended/extract_feature_sequence.h"
 #include "extended/feature_node.h"
 #include "extended/feature_node_iterator_api.h"
-#include "extended/feature_type.h"
-#include "extended/globalchaining.h"
+#include "extended/feature_type_api.h"
+#include "extended/globalchaining_api.h"
 #include "extended/node_visitor_api.h"
 #include "extended/reverse_api.h"
 #include "ltr/ltrdigest_def.h"
