@@ -21,17 +21,17 @@
 #include <sys/types.h>
 #include <unistd.h>
 
-#include "core/chardef.h"
-#include "core/compat.h"
-#include "core/error.h"
-#include "core/fa.h"
+#include "core/chardef_api.h"
+#include "core/compat_api.h"
+#include "core/error_api.h"
+#include "core/fa_api.h"
 #include "core/format64.h"
 #include "core/mapspec.h"
-#include "core/mathsupport.h"
-#include "core/minmax.h"
+#include "core/mathsupport_api.h"
+#include "core/minmax_api.h"
 #include "core/safecast-gen.h"
 #include "core/spacecalc.h"
-#include "core/str.h"
+#include "core/str_api.h"
 #include "core/types_api.h"
 #include "core/unused_api.h"
 #include "match/bcktab.h"
@@ -1311,7 +1311,7 @@ size_t gt_bcktab_sizeforlcpvalues(const GtBcktab *bcktab)
                     bcktab->maxbucketinfo.specialsmaxbucketsize;
   sizelcps
     = sizeof (GtUword) * gt_bcktab_nonspecialsmaxsize(bcktab);
-  return MAX(sizelcps,sizespeciallcps);
+  return GT_MAX(sizelcps,sizespeciallcps);
 }
 
 GtUword gt_bcktab_maxbucketsize(const GtBcktab *bcktab)
@@ -1403,7 +1403,7 @@ void gt_bcktab_consistencyofsuffix(int line,
     }
     cc = gt_encseq_get_encoded_char(encseq,suffix->startpos + idx,
                                            readmode);
-    if (ISSPECIAL(cc))
+    if (GT_ISSPECIAL(cc))
     {
       firstspecial = idx;
       break;
