@@ -19,7 +19,7 @@
 #define FMI_SUFBWTSTREAM_H
 
 #include <stdbool.h>
-#include "core/chardef.h"
+#include "core/chardef_api.h"
 #include "core/str_array.h"
 #include "core/logger_api.h"
 #include "core/error_api.h"
