@@ -15,10 +15,10 @@
   OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */
 
-#include "core/arraydef.h"
+#include "core/arraydef_api.h"
 #include "core/disc_distri_api.h"
-#include "core/fa.h"
-#include "core/ma.h"
+#include "core/fa_api.h"
+#include "core/ma_api.h"
 #include "core/intbits.h"
 #include "core/log_api.h"
 #include "core/spacecalc.h"
