@@ -19,10 +19,10 @@
 #include <limits.h>
 
 #include "core/assert_api.h"
-#include "core/chardef.h"
+#include "core/chardef_api.h"
 #include "core/encseq.h"
 #include "core/ma_api.h"
-#include "core/minmax.h"
+#include "core/minmax_api.h"
 #include "core/types_api.h"
 #include "match/seqabstract.h"
 #include "match/extend-offset.h"
@@ -212,13 +212,13 @@ GtUword gt_seqabstract_lcp(bool rightextension,
 
   gt_assert(useq != NULL && vseq != NULL &&
             useq->len >= u_start && vseq->len >= v_start);
-  maxlen = MIN(useq->len - u_start, vseq->len - v_start);
+  maxlen = GT_MIN(useq->len - u_start, vseq->len - v_start);
   for (lcp = 0; lcp < maxlen; lcp++)
   {
     GtUchar u_cc, v_cc;
 
     u_cc = gt_seqabstract_get_encoded_char(rightextension,useq,u_start + lcp);
-    if (ISSPECIAL(u_cc))
+    if (GT_ISSPECIAL(u_cc))
     {
       break;
     }
@@ -227,7 +227,7 @@ GtUword gt_seqabstract_lcp(bool rightextension,
       u_cc = GT_COMPLEMENTBASE(u_cc);
     }
     v_cc = gt_seqabstract_get_encoded_char(rightextension,vseq,v_start + lcp);
-    if (ISSPECIAL(v_cc))
+    if (GT_ISSPECIAL(v_cc))
     {
       break;
     }
@@ -253,12 +253,12 @@ char *gt_seqabstract_get(bool rightextension,const GtSeqabstract *seq)
   {
     GtUchar cc = gt_seqabstract_get_encoded_char(rightextension,seq,idx);
 
-    if (cc == WILDCARD)
+    if (cc == GT_WILDCARD)
     {
       buffer[idx] = '#';
     } else
     {
-      if (cc == SEPARATOR)
+      if (cc == GT_SEPARATOR)
       {
         buffer[idx] = '$';
       } else
